"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function _path() {
  const data = _interopRequireDefault(require("path"));

  _path = function () {
    return data;
  };

  return data;
}

function _fsExtra() {
  const data = _interopRequireDefault(require("fs-extra"));

  _fsExtra = function () {
    return data;
  };

  return data;
}

function _commentJson() {
  const data = _interopRequireDefault(require("comment-json"));

  _commentJson = function () {
    return data;
  };

  return data;
}

function _constants() {
  const data = require("../constants");

  _constants = function () {
    return data;
  };

  return data;
}

function _e2eFsHelper() {
  const data = _interopRequireDefault(require("./e2e-fs-helper"));

  _e2eFsHelper = function () {
    return data;
  };

  return data;
}

function _e2eScopes() {
  const data = _interopRequireDefault(require("./e2e-scopes"));

  _e2eScopes = function () {
    return data;
  };

  return data;
}

class BitMapHelper {
  constructor(scopes, fsHelper) {
    this.scopes = scopes;
    this.fs = fsHelper;
  }

  read(bitMapPath = _path().default.join(this.scopes.localPath, _constants().BIT_MAP), withoutComment = true) {
    const map = _fsExtra().default.readFileSync(bitMapPath) || {}; // $FlowFixMe

    return _commentJson().default.parse(map.toString('utf8'), null, withoutComment);
  }

  readWithoutVersion() {
    const bitMap = this.read();
    delete bitMap.version;
    return bitMap;
  }

  write(bitMap) {
    const bitMapPath = _path().default.join(this.scopes.localPath, _constants().BIT_MAP);

    return _fsExtra().default.writeJSONSync(bitMapPath, bitMap, {
      spaces: 2
    });
  }

  delete() {
    return this.fs.deletePath(_constants().BIT_MAP);
  }

  create(cwd = this.scopes.localPath, // $FlowFixMe
  componentObject = {
    'bar/foo': {
      files: [{
        relativePath: 'bar/foo.js',
        test: false,
        name: 'foo.js'
      }],
      mainFile: 'bar/foo.js',
      origin: 'AUTHORED'
    }
  }, oldBitMapFile = false) {
    const bitmapFile = _path().default.join(cwd, oldBitMapFile ? '.bit.map.json' : _constants().BIT_MAP);

    const bitmap = {
      version: '0.11.1-testing'
    }; // $FlowFixMe

    Object.keys(componentObject).forEach(key => bitmap[key] = componentObject[key]);

    _fsExtra().default.ensureFileSync(bitmapFile);

    return _fsExtra().default.writeJsonSync(bitmapFile, bitmap, {
      spaces: 2
    });
  }

  printFilesInCaseOfError(files) {
    const filesStr = files.map(f => f.name).join(', ');
    return `Files in bitmap file: ${filesStr}`;
  }

}

exports.default = BitMapHelper;