"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function _path() {
  const data = _interopRequireDefault(require("path"));

  _path = function () {
    return data;
  };

  return data;
}

function _fsExtra() {
  const data = _interopRequireDefault(require("fs-extra"));

  _fsExtra = function () {
    return data;
  };

  return data;
}

function _chai() {
  const data = require("chai");

  _chai = function () {
    return data;
  };

  return data;
}

function _constants() {
  const data = require("../constants");

  _constants = function () {
    return data;
  };

  return data;
}

function _defaultErrorHandler() {
  const data = _interopRequireDefault(require("../cli/default-error-handler"));

  _defaultErrorHandler = function () {
    return data;
  };

  return data;
}

function _utils() {
  const data = require("../utils");

  _utils = function () {
    return data;
  };

  return data;
}

function _e2eHelper() {
  const data = require("./e2e-helper");

  _e2eHelper = function () {
    return data;
  };

  return data;
}

function _e2eNpmHelper() {
  const data = _interopRequireDefault(require("./e2e-npm-helper"));

  _e2eNpmHelper = function () {
    return data;
  };

  return data;
}

function _e2eCommandHelper() {
  const data = _interopRequireDefault(require("./e2e-command-helper"));

  _e2eCommandHelper = function () {
    return data;
  };

  return data;
}

function _e2eScopes() {
  const data = _interopRequireDefault(require("./e2e-scopes"));

  _e2eScopes = function () {
    return data;
  };

  return data;
}

class GeneralHelper {
  constructor(scopes, npmHelper, commandHelper) {
    this.scopes = scopes;
    this.npm = npmHelper;
    this.command = commandHelper;
  }

  indexJsonPath() {
    return _path().default.join(this.scopes.localPath, '.bit/index.json');
  }

  getIndexJson() {
    return _fsExtra().default.readJsonSync(this.indexJsonPath());
  }

  writeIndexJson(indexJson) {
    return (0, _e2eHelper().ensureAndWriteJson)(this.indexJsonPath(), indexJson);
  }

  installAndGetTypeScriptCompilerDir() {
    this.npm.installNpmPackage('typescript');
    return _path().default.join(this.scopes.localPath, 'node_modules', '.bin');
  }

  setProjectAsAngular() {
    this.npm.initNpm();
    this.npm.installNpmPackage('@angular/core');
  }

  nodeStart(mainFilePath, cwd) {
    return this.command.runCmd(`node ${mainFilePath}`, cwd);
  }

  runWithTryCatch(cmd, cwd = this.scopes.localPath) {
    let output;

    try {
      output = this.command.runCmd(cmd, cwd);
    } catch (err) {
      output = err.toString() + err.stdout.toString();
    }

    return output;
  }

  static alignOutput(str) {
    if (!str) return str; // on Mac the directory '/var' is sometimes shown as '/private/var'
    // $FlowFixMe

    return (0, _utils().removeChalkCharacters)(str).replace(/\/private\/var/g, '/var');
  }

  expectToThrow(cmdFunc, error) {
    let output;

    try {
      cmdFunc();
    } catch (err) {
      output = err.toString();
    }

    const errorString = (0, _defaultErrorHandler().default)(error);
    (0, _chai().expect)(GeneralHelper.alignOutput(output)).to.have.string(GeneralHelper.alignOutput(errorString));
  }

  getRequireBitPath(box, name) {
    return `@bit/${this.scopes.remote}.${box}.${name}`;
  }

  getBitVersion() {
    return _constants().BIT_VERSION;
  }

  generateRandomTmpDirName() {
    return _path().default.join(this.scopes.e2eDir, (0, _e2eHelper().generateRandomStr)());
  }

}

exports.default = GeneralHelper;