"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function _glob() {
  const data = _interopRequireDefault(require("glob"));

  _glob = function () {
    return data;
  };

  return data;
}

function _path() {
  const data = _interopRequireDefault(require("path"));

  _path = function () {
    return data;
  };

  return data;
}

function _fsExtra() {
  const data = _interopRequireDefault(require("fs-extra"));

  _fsExtra = function () {
    return data;
  };

  return data;
}

function _e2eCommandHelper() {
  const data = _interopRequireDefault(require("./e2e-command-helper"));

  _e2eCommandHelper = function () {
    return data;
  };

  return data;
}

function _e2eScopeHelper() {
  const data = _interopRequireDefault(require("./e2e-scope-helper"));

  _e2eScopeHelper = function () {
    return data;
  };

  return data;
}

function _e2eScopes() {
  const data = _interopRequireDefault(require("./e2e-scopes"));

  _e2eScopes = function () {
    return data;
  };

  return data;
}

class GitHelper {
  constructor(scopes, commandHelper, scopeHelper) {
    this.scopes = scopes;
    this.command = commandHelper;
    this.scopeHelper = scopeHelper;
  }

  writeGitIgnore(list) {
    const gitIgnorePath = _path().default.join(this.scopes.localPath, '.gitignore');

    return _fsExtra().default.writeFileSync(gitIgnorePath, list.join('\n'));
  }

  writeToGitHook(hookName, content) {
    const hookPath = _path().default.join(this.scopes.localPath, '.git', 'hooks', hookName);

    return _fsExtra().default.outputFileSync(hookPath, content);
  }

  initNewGitRepo() {
    return this.command.runCmd('git init');
  }

  addGitConfig(key, val, location = 'local') {
    return this.command.runCmd(`git config --${location} ${key} ${val}`);
  }

  unsetGitConfig(key, location = 'local') {
    return this.command.runCmd(`git config --unset --${location} ${key}`);
  }

  mimicGitCloneLocalProject(cloneWithComponentsFiles = true) {
    _fsExtra().default.removeSync(_path().default.join(this.scopes.localPath, '.bit'));

    if (!cloneWithComponentsFiles) _fsExtra().default.removeSync(_path().default.join(this.scopes.localPath, 'components')); // delete all node-modules from all directories

    const directories = _glob().default.sync(_path().default.normalize('**/'), {
      cwd: this.scopes.localPath,
      dot: true
    });

    directories.forEach(dir => {
      if (dir.includes('node_modules')) {
        _fsExtra().default.removeSync(_path().default.join(this.scopes.localPath, dir));
      }
    });
    this.scopeHelper.initWorkspace();
  }

}

exports.default = GitHelper;